pub enum Block {
Txt(TextBlock),
Img(ImageBlock),
Tdo(TodoBlock),
Fnc(FunctionBlock),
Api(ApiBlock),
Lfc(LifecycleBlock),
Chr(CharacterBlock),
Emo(EmotionBlock),
Enc(EncryptionBlock),
Orc(OrchestrationBlock),
}Expand description
A typed block payload.
Variants
Txt(TextBlock)
See TextBlock.
Img(ImageBlock)
See ImageBlock.
Tdo(TodoBlock)
See TodoBlock.
Fnc(FunctionBlock)
See FunctionBlock.
Api(ApiBlock)
See ApiBlock.
Lfc(LifecycleBlock)
See LifecycleBlock.
Chr(CharacterBlock)
See CharacterBlock.
Emo(EmotionBlock)
See EmotionBlock.
Enc(EncryptionBlock)
See EncryptionBlock.
Orc(OrchestrationBlock)
See OrchestrationBlock.
Implementations
Sourceimpl Block
impl Block
Sourcepub fn payload(&self) -> Result<Vec<u8>>
pub fn payload(&self) -> Result<Vec<u8>>
Serializes the inner block struct to JSON bytes (the type is carried by the container, not embedded in the payload).
Sourcepub fn from_payload(tag: BlockTag, bytes: &[u8]) -> Result<Block>
pub fn from_payload(tag: BlockTag, bytes: &[u8]) -> Result<Block>
Inverse of Block::payload: parses a JSON payload for tag.
Sourcepub fn as_encryption(&self) -> Option<&EncryptionBlock>
pub fn as_encryption(&self) -> Option<&EncryptionBlock>
If this is an Enc block, returns the encryption directive.